package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````0!P```````!``````````)@!`0``
M`````````$``.``*`$``&@`9``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```"4`@``````
M`)0"````````E`(````````;`````````!L``````````0`````````!````
M!0```````````````````````````````````/B9````````^)D`````````
M``$```````$````&````@/L```````"`^P$``````(#[`0``````"`4`````
M```P!0```````````0```````@````8```"0^P```````)#[`0``````D/L!
M```````0`@```````!`"````````"``````````$````!````'`"````````
M<`(```````!P`@```````"0`````````)``````````$``````````0````$
M````V)D```````#8F0```````-B9````````(``````````@``````````0`
M````````4.5T9`0````@D@```````""2````````()(````````,`0``````
M``P!````````!`````````!1Y71D!@``````````````````````````````
M```````````````````````````0`````````%+E=&0$````@/L```````"`
M^P$``````(#[`0``````@`0```````"`!`````````$`````````!````!0`
M```#````1TY5`"7T#S3@Y[KVB+3YK^.$00S6^S/]+VQI8B]L9"UL:6YU>"UA
M87)C:#8T+G-O+C$```$````!`````0``````````````````````````````
M``````````````````````````````````````,`"@#X%0``````````````
M``````````,`%@````(`````````````````<0```!(`````````````````
M````````S0$``!(`````````````````````````>P```!(`````````````
M````````````>P$``!(`````````````````````````G`$``!(`````````
M````````````````/@(``!(`````````````````````````U`$``!(`````
M````````````````````AP```!(``````````````````````````0```"``
M````````````````````````'P(``!(`````````````````````````&`(`
M`!(`````````````````````````VP$``!(`````````````````````````
MN0```!(`````````````````````````_@(``!$`````````````````````
M````80```!(`````````````````````````M0(``!(`````````````````
M````````YP```!(`````````````````````````*`(``!(`````````````
M````````````EP$``!(`````````````````````````Q0$``!(`````````
M````````````````I`$``!(`````````````````````````@@(``"(`````
M````````````````````$````"``````````````````````````W````!(`
M````````````````````````+````"``````````````````````````M0$`
M`!(`````````````````````````V@(``!(`````````````````````````
M6P(``!(`````````````````````````K@(``!(`````````````````````
M````=`(``!$`````````````````````````U`(``!(`````````````````
M````````4P```!(`````````````````````````)P$``!8`````````````
M````````````!`$``!(`````````````````````````6P$``!(`````````
M````````````````ZP$``!(`````````````````````````J````!(`````
M````````````````````]0```!(`````````````````````````IP(``!(`
M````````````````````````PP(``!(`````````````````````````[`(`
M`!(`````````````````````````\0$``!(`````````````````````````
M3`(``!(`````````````````````````S0```!(`````````````````````
M````A@$``!(`````````````````````````"0(``!(`````````````````
M````````F@```!(`````````````````````````(`$``!(`````````````
M````````````3P$``!(`````````````````````````6@(``!(`````````
M````````````````O`(``!(`````````````````````````GP(``!(`````
M````````````````````]@$``!(`````````````````````````K@$``!(`
M````````````````````````.@$``!(`````````````````````````D0(`
M`!(`````````````````````````%`$``!(`````````````````````````
M`P(``!(`````````````````````````>P(``!(`````````````````````
M````1@```!$`````````````````````````=@```!(`````````````````
M````````P@```!(`````````````````````````;`$``!(`````````````
M````````````8@(``!(`````````````````````````X@(``!$`````````
M````````````````O@$``!(`````````````````````````Y`$``!(`````
M````````````````````,`(``!(`````````````````````````Y`(``!$`
M````````````````````````F`(``!(``````````````````````````%]?
M9VUO;E]S=&%R=%]?`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?251-
M7W)E9VES=&5R5$U#;&]N951A8FQE`%!,7V1O7W5N9'5M<`!097)L7W-Y<U]T
M97)M`%!E<FQ?9W9?9F5T8VAP=@!P97)L7V9R964`4&5R;%]G971?<W8`4&5R
M;%]A=&9O<FM?=6YL;V-K`'!E<FQ?9&5S=')U8W0`4&5R;%]N97=84U]F;&%G
M<P!P97)L7W)U;@!097)L7VYE=UA3`%!E<FQ?<W9?<V5T<'9N`'!E<FQ?86QL
M;V,`4&5R;%]S=E]S971P=@!P97)L7V-O;G-T<G5C=`!B;V]T7T1Y;F%,;V%D
M97(`4&5R;%]S869E<WES;6%L;&]C`%!,7V-U<G)E;G1?8V]N=&5X=`!097)L
M7V-R;V%K7VYO8V]N=&5X=`!097)L7VUG7W-E=`!097)L7V%T9F]R:U]L;V-K
M`%!E<FQ?<WES7VEN:70S`'!E<FQ?<&%R<V4`7U]S=&%C:U]C:&M?9F%I;`!E
M>&ET`&QS965K-C0`<F5A9&1I<C8T`'-T<F1U<`!C;&]S961I<@!O<&5N-C0`
M<W1R<F-H<@!U;FQI;FL`<W1R=&]K`&=E='!W=6ED`'-T<FQE;@!R;61I<@!R
M96%D`%]?;65M8W!Y7V-H:P!M:V1I<@!?7W9F<')I;G1F7V-H:P!G971P:60`
M<F5A9&QI;FL`<F5A;&QO8P!?7W-P<FEN=&9?8VAK`%]?;65M;6]V95]C:&L`
M7U]F<')I;G1F7V-H:P!L<W1A=#8T`%]?;&EB8U]S=&%R=%]M86EN`'-T9&5R
M<@!M96UC:'(`7U]C>&%?9FEN86QI>F4`<W1R8VAR`&UE;7-E=`!O<&5N9&ER
M`&=E='5I9`!A8V-E<W,`;65M8W!Y`'-T<F-M<`!?7V5R<FYO7VQO8V%T:6]N
M`&%B;W)T`'-T<FYC;7``7U]E;G9I<F]N`%]?<F5G:7-T97)?871F;W)K`%]?
M<W1A8VM?8VAK7V=U87)D`&QI8G!E<FPN<V\N-2XT,`!L:6)C+G-O+C8`;&0M
M;&EN=7@M86%R8V@V-"YS;RXQ`$=,24)#7S(N,3<`1TQ)0D-?,BXS-`!'3$E"
M0U\R+C,S```````````!``(``0`!``(``@`"``$``0`"``(``@`!``,``0`"
M``$``@`"``(``@`"``$``0`!``(``@`$``(``@`"``$``0`!``$``@`!``$`
M`@`"``(``@`"``$``@`"``$``@`!``0``@`"``(``@`!``(``0`"``(``0`"
M``$``0`%``(``@`"``(``@`"```````!``$`*@,``!`````@````EY&6!@``
M`P!``P````````$``P`@`P``$`````````"TD98&```%`$L#```0````LY&6
M!@``!`!6`P``$````)>1E@8```(`0`,```````"`^P$```````,$````````
M8!T```````"(^P$```````,$````````#!T```````#X_P$```````,$````
M`````!H````````(``(```````,$````````"``"```````@``(```````,$
M````````8%0````````H``(```````,$````````\%`````````X``(`````
M``,$````````X%$```````!```(```````,$````````0%0```````!(``(`
M``````,$````````2%0```````!0``(```````,$````````4%0```````!8
M``(```````,$````````6%0```````!H``(```````,$````````*%0`````
M``!P``(```````,$````````,%0```````"```(```````,$````````:%0`
M``````"8_P$```````$$```*``````````````"@_P$```````$$```+````
M``````````"H_P$```````$$```0``````````````"P_P$```````$$```8
M``````````````"X_P$```````$$```9``````````````#`_P$```````$$
M```;``````````````#(_P$```````$$```@``````````````#0_P$`````
M``8$```C``````````````#8_P$```````$$```D``````````````#@_P$`
M``````$$```E``````````````#H_P$```````$$```^``````````````#P
M_P$```````$$``!'``````````````"X_0$```````($```#````````````
M``#`_0$```````($```$``````````````#(_0$```````($```%````````
M``````#0_0$```````($```&``````````````#8_0$```````($```'````
M``````````#@_0$```````($```(``````````````#H_0$```````($```)
M``````````````#P_0$```````($```+``````````````#X_0$```````($
M```,````````````````_@$```````($```-```````````````(_@$`````
M``($```.```````````````0_@$```````($```/```````````````8_@$`
M``````($```1```````````````@_@$```````($```2```````````````H
M_@$```````($```3```````````````P_@$```````($```4````````````
M```X_@$```````($```5``````````````!`_@$```````($```6````````
M``````!(_@$```````($```7``````````````!0_@$```````($```8````
M``````````!8_@$```````($```:``````````````!@_@$```````($```<
M``````````````!H_@$```````($```=``````````````!P_@$```````($
M```>``````````````!X_@$```````($```?``````````````"`_@$`````
M``($```A``````````````"(_@$```````($```B``````````````"0_@$`
M``````($```F``````````````"8_@$```````($```G``````````````"@
M_@$```````($```H``````````````"H_@$```````($```I````````````
M``"P_@$```````($```J``````````````"X_@$```````($```K````````
M``````#`_@$```````($```L``````````````#(_@$```````($```M````
M``````````#0_@$```````($```N``````````````#8_@$```````($```O
M``````````````#@_@$```````($```P``````````````#H_@$```````($
M```Q``````````````#P_@$```````($```R``````````````#X_@$`````
M``($```S````````````````_P$```````($```T```````````````(_P$`
M``````($```U```````````````0_P$```````($```V```````````````8
M_P$```````($```W```````````````@_P$```````($```X````````````
M```H_P$```````($```Y```````````````P_P$```````($```Z````````
M```````X_P$```````($```[``````````````!`_P$```````($```\````
M``````````!(_P$```````($```]``````````````!0_P$```````($```_
M``````````````!8_P$```````($``!```````````````!@_P$```````($
M``!!``````````````!H_P$```````($``!"``````````````!P_P$`````
M``($``!$``````````````!X_P$```````($``!%``````````````"`_P$`
M``````($``!&``````````````"(_P$```````($``!(```````````````?
M(`/5_7N_J?T#`)&<`0"4_7O!J,`#7];P>[^I\```T!':1OD0PC:1(`(?UA\@
M`]4?(`/5'R`#U?```-`1WD;Y$.(VD2`"'];P``#0$>)&^1`"-Y$@`A_6\```
MT!'F1OD0(C>1(`(?UO```-`1ZD;Y$$(WD2`"'];P``#0$>Y&^1!B-Y$@`A_6
M\```T!'R1OD0@C>1(`(?UO```-`1]D;Y$*(WD2`"'];P``#0$?I&^1#"-Y$@
M`A_6\```T!'^1OD0XC>1(`(?UO```-`1`D?Y$`(XD2`"'];P``#0$09'^1`B
M.)$@`A_6\```T!$*1_D00CB1(`(?UO```-`1#D?Y$&(XD2`"'];P``#0$1)'
M^1"".)$@`A_6\```T!$61_D0HCB1(`(?UO```-`1&D?Y$,(XD2`"'];P``#0
M$1Y'^1#B.)$@`A_6\```T!$B1_D0`CF1(`(?UO```-`1)D?Y$"(YD2`"'];P
M``#0$2I'^1!".9$@`A_6\```T!$N1_D08CF1(`(?UO```-`1,D?Y$((YD2`"
M'];P``#0$39'^1"B.9$@`A_6\```T!$Z1_D0PCF1(`(?UO```-`1/D?Y$.(Y
MD2`"'];P``#0$4)'^1`".I$@`A_6\```T!%&1_D0(CJ1(`(?UO```-`12D?Y
M$$(ZD2`"'];P``#0$4Y'^1!B.I$@`A_6\```T!%21_D0@CJ1(`(?UO```-`1
M5D?Y$*(ZD2`"'];P``#0$5I'^1#".I$@`A_6\```T!%>1_D0XCJ1(`(?UO``
M`-`18D?Y$`([D2`"'];P``#0$69'^1`B.Y$@`A_6\```T!%J1_D00CN1(`(?
MUO```-`1;D?Y$&([D2`"'];P``#0$7)'^1"".Y$@`A_6\```T!%V1_D0HCN1
M(`(?UO```-`1>D?Y$,([D2`"'];P``#0$7Y'^1#B.Y$@`A_6\```T!&"1_D0
M`CR1(`(?UO```-`1AD?Y$"(\D2`"'];P``#0$8I'^1!"/)$@`A_6\```T!&.
M1_D08CR1(`(?UO```-`1DD?Y$((\D2`"'];P``#0$99'^1"B/)$@`A_6\```
MT!&:1_D0PCR1(`(?UO```-`1GD?Y$.(\D2`"'];P``#0$:)'^1`"/9$@`A_6
M\```T!&F1_D0(CV1(`(?UO```-`1JD?Y$$(]D2`"'];P``#0$:Y'^1!B/9$@
M`A_6\```T!&R1_D0@CV1(`(?UO```-`1MD?Y$*(]D2`"'];P``#0$;I'^1#"
M/9$@`A_6\```T!&^1_D0XCV1(`(?UO```-`1PD?Y$`(^D2`"'];P``#0$<9'
M^1`B/I$@`A_6```````````````````````````````````````````_(P/5
M_X,!T?U[`ZG]PP"1X!\`N>```-``U$?YXH<`J>(C`)'S4P2I]5L%J0$`0/GA
M%P#Y`0"`TN!S`)'A0P"1T/__E^(``-!"S$?YX```T`#P1_GA`P*J@@T`E.``
M`-``]$?Y``!`.4`)`#;@``#0`.A'^4'0.]7S``#P(6A@^"!H4CD`!``R(&@2
M.>`?0+D4#``1`!``$0!\?9.E__^7Y@M`^>,#`*I@0@*1P0!`^0,$`/D@``"0
M`&`0D6$``*G@``#P`4!`^2```)``@!"180`!J>`?0+D?!`!Q#0D`5"$`@-(D
M#``1Q7AA^"$$`)%EV"3X'P`!:VS__U0`#``1=4("D7_8(/@!``"PX@,4*B&0
M#Y$$`(#2H`Y`^='^_Y<`!0`T=$("D8`.0/E9__^7]@,`*N&3`)$@``"0`,`%
MD9```)1`!`"T<T("D6`.0/FX_O^7'___E^```-``U$?YXA=`^0$`0/E"``'K
M`0"`TN$$`%3]>T.IX`,6*O-31*GU6T6I_X,!D;\C`]7``U_6^/[_E_,``/!B
M0@*10`P`^2`#`+07__^7X```T`#H1_E!T#O5(FA@^%]8)#FP__\7H`Y`^<?^
M_Y?7__\7@`I`^6```+3,!P"4W/__%^&3`)$@``"0`.`#D68``)2`"@#YP/K_
MM,0'`)34__\7@`"`4L#__Q<@`(!2RO[_EQG__Y<?(`/5'R`#U1\@`]4?(`/5
M'R`#U1\@`]4?(`/5'R`#U1\@`]4?(`/5'R`#U1\@`]4?(`/5'0"`TAX`@-+E
M`P"JX0-`^>(C`)'F`P"1X```T`#\1_D#`(#2!`"`TDG__Y?4_O^7X```T`#0
M1_E```"TB/[_%\`#7]8?(`/5'R`#U1\@`]4?(`/5'R`#U1\@`]7@``#P`"`"
MD>$``/`A(`*1/P``Z\```%3A``#0(=Q'^6$``+3P`P&J``(?UL`#7];@``#P
M`"`"D>$``/`A(`*1(0``RR+\?]-!#(&+(?Q!D\$``+3B``#00N!'^6(``+3P
M`P*J``(?UL`#7]8_(P/5_7N^J?T#`)'S"P#Y\P``\&`B0CE``0`WX```T`#8
M1_F```"TX```\``$0/F)_O^7V/__ER``@%)@(@(Y\PM`^?U[PJB_(P/5P`-?
MUA\@`]5?)`/5V___%Q\@`]4?(`/5'R`#U1\@`]4?(`/5'R`#U3\C`]7]>[RI
M_0,`D?=C`ZGX`P&JX0``T"'X1_GS4P&I-P!`^7<&`+3U6P*I%0"`4@$`0#D_
M]`!Q)!A`>D$#`%3S`D#Y,P(`M/8#`*JU?D"3]`,7JA\@`]4?(`/5'R`#U>(#
M%:KA`Q:JX`,3JFG^_Y>````U8&IU.!_T`'$@`@!4DXY`^//^_[7U6T*IX`,3
MJO-30:GW8T.I_7O$J+\C`]7``U_6]0,`JJ$>0#@_]`!Q)!A`>J'__U2U`@!+
MX?__%X`"%\NU!@"1<P(5BP#\0Y,``P"YX`,3JO5;0JGS4T&I]V-#J?U[Q*B_
M(P/5P`-?UA,`@-+F__\7'R`#U1\@`]4_(P/5_\,"T>$``-`AU$?Y_7L)J?U#
M`I'S4P#Y\P,`JB(`0/GB1P#Y`@"`TN$C`)&$_O^78`(`->$;0+D"`)12(0P4
M$C\00'$D$$)ZX`$`5.$``-`AU$?YXT=`^2(`0/EC``+K`@"`TL$!`%3S4T#Y
M_7M)J?_#`I&_(P/5P`-?U@``@%+S__\7X`,3JD$`@%(H_O^7'P``<>`7GQKM
M__\75/[_ES\C`]7_0P/1X0``T"'41_G]>PJI_8,"D2(`0/GB3P#Y`@"`TL``
M`+3S4PNI\P,`J@$`0#FA`0`U\U-+J>```-``U$?YXD]`^0$`0/E"``'K`0"`
MTD$)`%3]>TJI_T,#D;\C`]7``U_6]5L,J53^_Y?U`P"JP`8`M.`#%:KL_?^7
MX`4`M`%,0#D43`"1/[@`<6$``%2!!D`Y`?__-`!,0#D?N`!QH`4`5.`#$ZIX
M_O^7]@,`JN`#%*IU_O^7P@(`"T((`!%"?$"3X@<`^>`#`JHK_O^7]@,`JN('
M0/GE`Q2JY`,3J@,``/!C(`*100"`4FO^_Y?A8P"1X`,6JN#]_Y<?!``QH```
M5.`K0+D`#!02'Q!`<>`"`%3@`Q:J@/W_E^`#%JI&_O^7X`,5JL#]_Y>@^O^U
M'R`#U1\@`]7@`Q6JQ_W_E^`#$ZK=_?^7\U-+J?5;3*FZ__\7@`9`.1^X`'%!
M^O]4@`I`.8#X_S3/__\7X`,6JJ/__Y?J__\7\U,+J?5;#*GR_?^7/R,#U?^#
M`=']>P*I_8,`D?-3`ZGS`P"JX```L`#41_GU6P2I]V,%J0(`0/GB#P#Y`@"`
MTB``0#D?]`!Q-!2!FN`#%*HP_O^7]0,`JN%3`)'@`Q.J(/__EX`(`+3V`P"J
M*?[_E[\"`.LI!P!4]A>`N?<``+#W^D?YUO)]TV`"0#D?]`!Q!!A`>J`,`%3C
M`Q.J'R`#U6`<0#@?]`!Q!!A`>J'__U1C`!/+8WQ`D_@"0/F@"@"1```#B\_]
M_Y<`:S;XH`(`M.`"0/D#:';X8`)`.6```#D?]`!Q!!A`>N```%1@!@"1`A1`
M.&(<`#A?]`!Q1!A`>H'__U2@!X!28!0`.```@-*":F`X8F@@.``$`)&B__\U
MX```L`#41_GB#T#Y`0!`^4(``>L!`(#2(0@`5/U[0JGS4T.I]5M$J?=C1:G_
M@P&1OR,#U<`#7]8!`(#2'R`#U8)J83C":B$X(00`D:+__S7L__\7]P``L/?Z
M1_GX`D#Y``-`^6`%`+3@`QBJ!`"`4@&,0/CB`P0JA`0`$:'__[5!#``1(7Q]
MD^```-#D!P"Y`I!`N:("`#4B`(!2`I``N>`#`:KA!P#YCOW_EZ#Z_[3C!T#Y
MX0,8JN0'0+GD!P"YX`<`^99\?9/B`Q:J_?S_E^0'0+GE!T#YY0(`^80$`!&_
MV"3XH?__%^`#&*H=_?^7X`(`^>4#`*I`^/^TY`=`N99\?9/V__\7`P"`TJ/_
M_Q<!`H#2!`"`4MS__Q=E_?^7/R,#U?U[O:D-!(+2_0,`D?-3`:GU$P#Y_V,M
MR_\#`OGT`P"JX```L`#41_GU`P&J\V,`D>+_@=(!`$#YX0\(^0$`@-(```#P
MX0,3J@!``I'@_/^7'P``<<T``%0"?$"3``0`46'*8#@!`P`UP`(`->```+``
MZ$?Y0]`[U>(#%:KA`Q2J8&A@^.K\_Y?@``"P`-1'^>(/2/D!`$#Y0@`!ZP$`
M@-+A`@!4#02"TO]C+8OU$T#Y\U-!J?U[PZB_(P/5P`-?U@)\0)/@`Q.JX06`
M4N('`/EG_?^7P/S_M.```+``Z$?Y1-`[U>,'0/GB`Q.JX0,4JH!H8/@B_?^7
MY/__%R3]_Y<_(P/5_7N^J2,``/`!``#P_0,`D6-@!Y'S4P&I5-`[U?,``+!S
MZD?YX@``L$+L1_DA@`*1@&IS^%7]_Y>`:G/X!```\/-30:F$0!"1_7O"J+\C
M`]7C`P2J!0"`4@(``+`!``#P0H`CD2$``Y'H_/\7'R`#U1\@`]4?(`/57R0#
MU>```+``Z$?Y1-`[U>(``+!"[$?Y(P``\`$``/!C8`>1@&A@^"&``I$Y_?\7
M/R,#U?U[O:D-!H32_0,`D?-3`:G_8RW+_P,"^>```+``U$?Y%`"`T@$`0/GA
M%Q#Y`0"`TG_\_Y?D`P`J(@""TD$`@%+@8P"1!0``\`,``/"E8`.18X`#D3;]
M_Y<#!(+2X&,`D>%C(XL"`(+2;?S_EP`"^#<#!``1\P,`JF-\0)/C!P#YX`,#
MJN+\_Y?T`P"J``$`M.,'0/ES?D"3X@,3J@$$@M+A8R&+[OS_EY]J,SC@``"P
M`-1'^>(74/D!`$#Y0@`!ZP$`@-(!`0!4#0:$TO]C+8O@`Q2J\U-!J?U[PZB_
M(P/5P`-?UO4K$/F]_/^77R0#U</__Q<_(P/5_7N[J0T2@M+]`P"1\U,!J?5;
M`JG_8RW+_P,"^?4#`*K@``"P`-1'^?,#`:H!`$#YX4<(^0$`@-(```#PX1,`
MD0#@`Y'L_?^7]`,`JN$%@%+@`Q6JT/S_EX`"`+3A`Q6J````\``@!)&N_O^7
MX`,5JN$``+`AU$?YXT=(^2(`0/EC``+K`@"`TL$-`%0-$H+2_V,MB_-30:GU
M6T*I_7O%J+\C`]7``U_6X`,3JK+\_Y<6``#PP6($D1/\_Y?S`P"JX/S_M```
M`/#X9PCY&```\!BC!)'Z;PCY&H`$D?=C"/GY:PCY8`)`.>`$`#2T``"TX0,3
MJN`#%*J3_/^7``,`-.`#$ZK(_/^7`@0`T?D#`*IB`@*+?P("ZZ,``%0*```4
M7_0?.'\"`NN```!40`!`.1^\`'%@__]4X`,3JKK\_Y?Y`P"JX`,5JK?\_Y<`
M`!F+``@`D1_\/_$)`P!4P6($D0``@-+H^_^7\P,`JL#[_[7W8TCY^&=(^?EK
M2/GZ;TCYM___%Y0``+2``D`Y'[@`<2`%`%3@`Q6J.0"`TJ+\_Y<``!F+``@`
MD1,``/!SP@.1'_P_\4C]_U3F`Q6JY0,:JN0#$ZKC`QBJ`@""TD$`@%+@(P*1
MF/S_E^$C`)'@(P*1#?S_E\#[_S7@&T"Y``P4$A\@0'%!^_]4X","D2$`@%()
M_/^7P/K_->$C`I$```#P`"`$D4/^_Y?@(P*15OS_E_=C2/GX9TCY^6M(^?IO
M2/F0__\7@`9`.2#Y_S36__\7]V,(^?AG"/GY:PCY^F\(^27\_Y<_(P/5_7N^
MJ>$%@%+]`P"1\PL`^?,#`*K2^_^7'P``\6`&@)KS"T#Y_7O"J+\C`]4\_/\7
M'R`#U1\@`]4?(`/5/R,#U?U[OJD-!(+2_0,`D?]C+<O_`P+YX0``L"'41_DB
M`$#YX@\(^0(`@-*`!@"T\QL(^?0?"/GT`P"J`0!`.:$%`#13_/^7`@0`D>,#
M`*I?!$#Q2`<`5/-C`)'A`Q2JX`,3JN,'`/F>^_^7XP=`^6`$`-%@`@"+'P`3
MZZ@``%0'```4'_0?.!\`$^N```!4`0!`.3^\`'%@__]4X`,3JN$%@%*?^_^7
MX`0`M!\`$^LH!`!4X`,3J@K\_Y?A``"P(=1'^>,/2/DB`$#Y8P`"ZP(`@-(!
M!0!4\QM(^0T$@M+T'TCY_V,MB_U[PJB_(P/5P`-?UO,;2/GT'TCYX```L`#4
M1_GB#TCY`0!`^4(``>L!`(#2(0,`5````/``P`.1#02"TO]C+8O]>\*HOR,#
MU>S[_Q<?```YW___%P``@-+?__\7X```L`#41_GB#TCY`0!`^4(``>L!`(#2
MP0``5/,;2/D```#P]!](^0#``Y'L__\7M_O_E_,;"/GT'PCYM/O_ES\C`]7_
M@P'1X```L`#41_G]>P&I_4,`D?-3`JD4``#PE,($D?5;`ZGW8P2I^2L`^?4`
M`+"U^D?Y`0!`^>$'`/D!`(#2X1,`D>`#%*KD_/^7X`$`M*("0/GC!X"Y0`P#
MBP$$0/E!>"/XX?[_M`$(0/D!!`#Y`"``D:'__[7A$P"1X`,4JM;\_Y=@_O^U
M]0``L+7Z1_D4``#PE`(%D>$3`)'@`Q2JSOS_E^`!`+2B`D#YXP>`N4`,`XL!
M!$#Y07@C^.'^_[0!"$#Y`00`^0`@`)&A__^UX1,`D>`#%*K`_/^78/[_M?4`
M`+"U^D?Y%```\)0B!9'A$P"1X`,4JKC\_Y?@`0"TH@)`^>,'@+E`#`.+`01`
M^4%X(_CA_O^T`0A`^0$$`/D`(`"1H?__M>$3`)'@`Q2JJOS_EV#^_[7U``"P
MM?I'^10``/"48@61X1,`D>`#%*JB_/^7(`(`M*("0/GC!X"Y0`P#BP$$0/E!
M>"/XX?[_M!\@`]4?(`/5`0A`^0$$`/D`(`"1H?__M>$3`)'@`Q2JDOS_ER#^
M_[7V``"PUOI'^10``/"5@@61X1,`D>`#%:J*_/^7(`(`M,("0/GC!X"Y0`P#
MBP$$0/E!>"/XX?[_M!\@`]4?(`/5`0A`^0$$`/D`(`"1H?__M>$3`)'@`Q6J
M>OS_ER#^_[7V``"PUOI'^14``/"UP@61X1,`D>`#%:IR_/^7(`(`M,("0/GC
M!X"Y0`P#BP$$0/E!>"/XX?[_M!\@`]4?(`/5`0A`^0$$`/D`(`"1H?__M>$3
M`)'@`Q6J8OS_ER#^_[7W``"P]_I'^14``/"VX@.1X1,`D>`#%JI:_/^7(`(`
MM.("0/GC!X"Y0`P#BP$$0/E!>"/XX?[_M!\@`]4?(`/5`0A`^0$$`/D`(`"1
MH?__M>$3`)'@`Q:J2OS_ER#^_[7X``"P&/M'^18``/#7`@:1X1,`D>`#%ZI"
M_/^7(`(`M`(#0/GC!X"Y0`P#BP$$0/E!>"/XX?[_M!\@`]4?(`/5`0A`^0$$
M`/D`(`"1H?__M>$3`)'@`Q>J,OS_ER#^_[7Y``"P.?M'^1<``/#X0@:1X1,`
MD>`#&*HJ_/^7(`(`M"(#0/GC!X"Y0`P#BP$$0/E!>"/XX?[_M!\@`]4?(`/5
M`0A`^0$$`/D`(`"1H?__M>$3`)'@`QBJ&OS_ER#^_[7Y``"P.?M'^1@``/`8
M@P:1X1,`D>`#&*H2_/^7(`(`M"(#0/GC!X"Y0`P#BP$$0/E!>"/XX?[_M!\@
M`]4?(`/5`0A`^0$$`/D`(`"1H?__M>$3`)'@`QBJ`OS_ER#^_[7Y``"P.?M'
M^1@``/`8(P21X1,`D>`#&*KZ^_^7(`(`M"(#0/GC!X"Y0`P#BP$$0/E!>"/X
MX?[_M!\@`]4?(`/5`0A`^0$$`/D`(`"1H?__M>$3`)'@`QBJZOO_ER#^_[4`
M``#PX1,`D0#`!I'E^_^7@```M.$#`*K@0@:1K/S_EP```/#A$P"1`"`'D=W[
M_Y>@``"TX0,`J@```/``@`>1H_S_EP```/#A$P"1`,`'D=3[_Y?``@"TX0,`
MJJ#B`Y&;_/^7X```L`#41_GB!T#Y`0!`^4(``>L!`(#2H0(`5/U[0:F`@@61
M]5M#J0$``/#S4T*I(6`(D?=C1*GY*T#Y_X,!D;\C`]6)_/\7````\.$3`)$`
M``B1NOO_ET#]_[3A`P"JP`(&D8'\_Y?F__\7</K_EQ\@`]4?(`/5'R`#U3\C
M`]7_@P#1X```L`#41_G]>P&I_4,`D0$`0/GA!P#Y`0"`T@```/#A$P"1```&
MD:3[_Y<``@"T``!`.1_``'$$&$!ZX`>?&N$``+`AU$?YXP=`^2(`0/EC``+K
M`@"`TN$``%3]>T&I_X,`D;\C`]7``U_6``"`4O3__Q=-^O^7/R,#U?\#!=']
M>P>I_<,!D>&+$*GA``"P(=1'^>.3$:GC`P"1Y9L2J>>?`/G@!P2MX@\%K>07
M!JWF'P>M(@!`^>(W`/D"`(#2X0,%D>&'`JGA`P21X@,`JN$?`/GA!H`2X4,`
MN>$/@!+A1P"Y00"`4OZ#PCS_@\,\X```L`#D1_G^`X`]_P>`/0``0/G^@X0\
M_X.%/"OZ_Y?@'X!2U?G_ES\C`]7]>[VI_0,`D?-3`:GU6P*I_T-`T?\#`OG_
M0P#1_P,"^>)#0)'A``"0(=1'^?8#`"HC`$#Y0P0`^0,`@-(!`(#20@"`4I+Y
M_Y<5!`#1X`,5ZZ$^0)(`/$"2($2`VK4"`.M$!@!4\P,`D?0``+#A`Q6JX`,6
M*@(`@%*%^?^7'P0`L>`%`%0"`8#2X0,3JN`#%BHB`*#R\OG_EQ\$`#&@!`!4
M`'Q`DQ\<`/&I`P!4`"``T6`"`*NC``!4&0``%``$`-$?`!/KPP(`5`$`0/F"
M"D#Y7P`!ZT'__U0``!/+```5B^$``)`AU$?YXT-`D60$0/DB`$#YA``"ZP(`
M@-)A`@!4_T,`D?]#0)'S4T&I]5M"J?U[PZB_(P/5P`-?UK5"0-&_0D"Q0?K_
M5```@)+M__\7````T`#`")&)__^7````T`"`")&&__^7T?G_ES\C`]7]>[^I
M_0,`D;7Y_Y=D^?^70```M```0/G]>\&HOR,#U<`#7]8?(`/5'R`#U3\C`]7_
M0P'1_7L"J?V#`)'U6P2I]0,`JN```)``U$?Y\U,#J1,``-`!`$#YX0\`^0$`
M@-)T`@F1X5,`D>`#%*KX^O^7@```M.8#`*H``$`Y``(`->```)``U$?YX@]`
M^0$`0/E"``'K`0"`TF$%`%3]>T*IX0,5JF`""9'U6T2I\U-#J?]#`9&_(P/5
ML/O_%^`#%:KF!P#Y[OG_E_,#`*K@!T#YZ_G_EW,"`(M@"@"1I/G_E^8'0/EB
M"@"100"`4O8#`*KD`Q6J!0``T`,``-"E8`218Z`$D>+Y_Y?@``"0`-1'^>(/
M0/D!`$#Y0@`!ZP$`@-(A`0!4_7M"J>$#%JK@`Q2J]5M$J?-30ZG_0P&1OR,#
MU8[[_Q=^^?^7'R`#U3\C`]7_@P;1_7L4J?T#!9'W8Q>I]P,`JN```)``U$?Y
M\U,5J?.#`)'U6Q:I]>,`D?1S`)$!`$#YX9\`^0$`@-+@``"P`$``D18``-`"
M#$&IX@\"J0*,1:GBCP.I'8#"/!Z`PSP?@,0\`1!`^6$*`/D`-$#YH`H`^>$#
M%*K`X@.1_?L"K?\?@#V>^O^7@```M`$`0#GX`P"J@2(`-?EK&*G[<QFI._G_
ME^KX_Y?`$`"T&P!`^9L0`+3@`QNJG?G_EQGX?],Y!P"1X`,9JE7Y_Y=D`T`Y
M^@,`JOP#&:KX`P"JA`(`-!4``-"U8@F1X@,9JN`#&JI!`(!2XP,5JI'Y_Y=:
M"P"1GP,9ZV0?0#B"(YF:00`9RSD+`-$A"`"1/P`"ZR$@@IHA``++.0`9BP3^
M_S4```#0^6,!D0"`!Y$#```4((=`^.`!`+3A`Q2J;?K_E_4#`*I@__^T`0!`
M.2'__S2H^O^7X/[_-.`#%:I%^?^7]0,`JJ`!`+4?(`/5'R`#U74"0/DU`0"T
MH`)`.:`+`#3@`Q6JF_K_EX`*`#5S(@"1=0)`^37__[7@`Q6J8?G_E_D#`*K@
M`QBJ7OG_ESD#``LY$Q`1&P``T#E_0)/@`QFJ%/G_E^<#&*IE@P21Y`,5JN(#
M&:H&``#0`P``T,:`"9%CH`F1^@,`JD$`@%)1^?^7X`,:J@$X@%(N^?^7'P0`
M,:$``%3C^/^7!0!`N;]$`'$!%0!4X0,"D>`#&JH%^?^7\P,`*J```#7@DT"Y
M``P4$A\00'&@!@!4X```D`#D1_D"``#0XP)`^>0#&JH``$#Y0N`*D4$`@%+:
M^/^7%0"`TN```)``U$?YXI]`^0$`0/E"``'K`0"`TD$>`%3]>U2IX`,5JOEK
M6*G[<UFI\U-5J?5;5JGW8U>I_X,&D;\C`]7``U_6\_C_E_L#`*I@`@"UM2(`
MD:`"0/D`$P"TX0,4J@SZ_Y=@__^T`0!`.<'^_S6U(@"1^/__%^`#%:KE^/^7
M]0,`JJ#U_[5S(@"1J?__%Q4`@-*I__\7"OG_EQGX?],Y!P"1;?__%_6;0+F=
M^/^7OP(`:R'Y_U3@DT"Y`"``$A\`!W&A^/]4X`,9JKGX_Y?A`Q2J]0,`J@``
M`-``0`R1[/G_E^`/`+3A`P"JX`)`^>K[_Y?X`P"J0`\`M.`#&*KP^/^7_`,`
MJA\,`'$M`@!4`'Q`DP$``-``$`#1(6`,D0`#`(NO^/^70`$`-9\3`'%@$P!4
MG!<`40#+?#@?O`!QX!(`5!\@`]4?(`/5'R`#U1<``-#A`Q2JX`(&D<WY_Y>@
M``"T``!`.1_``'$$&$!ZP0``5.`#&*H!`(!2S?C_E_0#`"H@"P`UX`(&D0$`
M`-`A8`B1BOK_EWN#!)$4``#0E$(0D1@``-`*^/^7&&,-D>8#`"KG`Q2JY0,;
MJN0#&JKB`QFJX`,5J@,``-!!`(!28R`-D;_X_Y<1```45?C_EP``0+D?1`!Q
M00(`5/GW_Y?T`P#Y<P8`$>8#`"KG`Q,JY0,;JN0#&JKC`QBJX@,9JN`#%:I!
M`(!2KOC_E^`#%:H!.(!2B_C_EQ\$`#&`_?]4X`,:JH_X_Y?A`Q6JP.(#D5_Z
M_Y?@`Q6JBO[_EVW__Q?@``"0`.1'^>0#&JKC`D#Y`@``T```0/E"X`F100"`
M4CSX_Y=B__\7?O[_E^```)``U$?YXI]`^0$`0/E"``'K`0"`TH$*`%3]>U2I
MX`,8JO-35:GU6U:I]V-7J?^#!I&_(P/55_C_%Z`!@-(]^/^7O`&`TAL``-#Z
M`P"J^`,`JOD#'*I[0PF19`J`4N;^_Q?X`D#YAO__%P+^_Y?X`P"JP/3_MP$H
M`-$"`(!2X`,4*J#W_Y?A`P21X`,4*L(`@-(0^/^7'Q@`\>$%`%3A`T&Y`&"(
M4B!HJ'(_``!KX?+_5.$+0GD`J8A2/P``:V'R_U0!RP#1`@"`4N`#%"J-]_^7
MX2,$D>`#%"H"!8#2_??_EQ^@`/&!`P!4YB,$D66#!)'D`QJJX@,9JN`#%:H'
M``#0`P``T.=`$)%CX`R100"`4O_#!#E/^/^7IO__%_<&0/F7[?^TX`,7JD;X
M_Y<?#`#Q">W_5``0`-$!``#0X`(`BR&`#)$'^/^7'P``<1@3EYI@__\7````
MT`"@#)&=_?^7Z/?_E_EK&*G[<QFIY??_ES\C`]7_0P'1X```D`#41_G]>P&I
M_4,`D?-3`JE4T#O5\P``D'/J1_GU6P.I]R,`^95J<_@!`$#YX0<`^0$`@-+A
M$P"1H,)".:#&`CD```#0`(`%D1/Y_Y>```"T`0!`.3_$`'%@"P!4%_S_EY5J
M<_C@`Q6J8P"`4B(`@%(!``#0(<`-D6/W_Y?U`P"J8`$`M``(0/D"``#00N`-
MD0$`0/F`:G/X8_?_EZ`*0/D!`$#Y(`Q`N0`*L#>`:G/X8P"`4B(`@%(!``#0
M]P``L"$`#I%0]_^7]0,`JH`!`+3A$P"1````T``@!)'N^/^7H0I`^2,`0/E`
M!P"TX@,`JN$#`ZJ`:G/X2_?_EY5J<_@B`(!2`0``T"$@#I'@`Q6J%??_EP(`
M`-#A`P"J0H`.D>`#%:I`]_^7@&IS^/1"`I'A$P"1'\0".0```-``X`.1U?C_
MEX`*`/GS`P"JP`(`M`$X@%+@`Q.JO_?_EP$$`!$_!`!Q!(A1>H$$`%3@``"0
M`-1'^>('0/D!`$#Y0@`!ZP$`@-*!`P!4]R-`^?U[0:GS4T*I]5M#J?]#`9&_
M(P/5P`-?UH`&0/G[_?^7@`H`^?,#`*K@_/^U````T`"@#I&9]_^7``1`.>#T
M_S2D__\7X$("D0`$0/D!`$#YX`,#J@7Z_Y?&__\7@&IS^';W_Y>O__\79/?_
ME_="`I'C`P`JX@,3J@```-``0`^1X09`^2$`0/F$]_^7/R,#U?_#`-']>P&I
M_4,`D?-3`JGS`P"JX```D`#41_D!`$#YX0<`^0$`@-(```#0X1,`D0``!I&1
M^/^7(`$`M```0#D?P`!Q!!A`>N`'GQI_`@#QX0>?&C\``&JA`0!4X```D`#4
M1_GB!T#Y`0!`^4(``>L!`(#2000`5/U[0:GS4T*I_\,`D;\C`]7``U_68`)`
M.6#^_S3@`Q.J(/O_E^$%@%+T`P"JY?;_EQ\``/&`!H":4O?_EP$``-""`(#2
M(8`)D?+V_Y?`_/\UX```D`#41_GB!T#Y`0!`^4(``>L!`(#2X0``5/U[0:G@
M`Q.J\U-"J?_#`)&_(P/5R?C_%QOW_Y<?(`/5'R`#U1\@`]4?(`/5'R`#U1\@
M`]7A``"0(=1'^3\C`]7]>[^I`^`!D1<$`$_]`P"1^.4`;_]#"M&9Y`!O(@!`
M^>)'`?D"`(#27.0`;P'@`)'B`P"1/GQ`;3T$P3S>.Y\.OP=@;]X+("[:.Y=.
M_E=83_]72$_>'SA._Q\Y3MX?OTZ_!UAOO0=(;_\?/$[_'[U.VQ^_3EJ,GTQ_
M``'KP?W_5/D?P#WAHP&1^.4`;^*C"9'_^T"M_?-!K?OK0JTA0`"1((#8/"$`
MWSSU'SQNWQ^^3B`<(&Z^'[U.G1^\3GP?NTX5'#5N6Q^Z3CH?N4ZV!F%OM8;U
M3M4>M4ZY'CA..8"`/%\``>O!_?]4!"!`J0480:GB*T"IB?Q;TP/]0M,I%02J
M8W@(JL$`!<IK?$"2(0`(B@<00/DA``;**4`IBR$SC])!4*OR0@`!BT(`!XM*
M`0&+*0$""^P+0/DB_5O30A0)JD(`"HMJ`07*2@$$BHP!`8M*`07*2@$&BT\`
M"@N"_$+30G@$JF,``LKJ_5O38P`)BDH5#ZIC``O*2@$,BV,`!8M-?$"23@$#
M"R/]0M-I>`FJXP]`^<K]6]-*%0ZJ+'U`DF,``8M*`0.+0P`)RF,`#XIC``W*
M8P`+B^(30/E1`0,+X_U"TRK^6]-C>`^J0@`!BTH5$:I*`0*+(@$#RD(`#HIK
M?$"20@`,RD(`#8M*`0(+POU"TT)X#JKN%T#Y8P`"RDG]6]-C`!&*S@$!BRD5
M"JIC``O**0$.BV,`#(M-?$"2,`$#"R/^0M-C>!&J0@`#R@G^6]-"``J**140
MJD(`#<IL?$"20@`+B^XO0ZG.`0&+:P$!BRD!#HLO`0(+0OU"TT)X"JIC``+*
MZ?U;TV,`$(HI%0^J8P`,RBD!"XMC``V+2GQ`DBX!`PL#_D+3[2-`^6-X$*I"
M``/*R?U;TT(`#XJM`0&+*14.JD(`"LI"``R+*0$-BRT!`@OB_4+30G@/JFM\
M0)+O)T#Y8P`"RJG]6]-C``Z*[P$!BRD5#:IC``O**0$/BV,`"HM,?$"2+P$#
M"\/]0M-C>`ZJ[BM`^4(``\KI_5O30@`-BLX!`8LI%0^J0@`,RBD!#HM"``N+
M:GQ`DBX!`@NB_4+30G@-JNTO0/EC``+*R?U;TV,`#XJM`0&+*14.JF,`"LHI
M`0V+8P`,BTM\0)(M`0,+X_U"TV-X#ZKO,T#Y0@`#RJG]6]-"``Z*[P$!BRD5
M#:I"``O**0$/BT(`"HML?$"2+P$""\+]0M-">`ZJ[C=`^6,``LKI_5O38P`-
MBLX!`8LI%0^J8P`,RBD!#HMC``N+2GQ`DBX!`PNC_4+38W@-JNT[0/E"``/*
MR?U;TT(`#XJM`0&+*14.JD(`"LHI`0V+0@`,BVM\0)(M`0(+XOU"TT)X#ZKO
M/T#Y8P`"RJG]6]-C``Z*[P$!BRD5#:IC``O**0$/BV,`"HM,?$"2+P$#"\/]
M0M-C>`ZJ[D-`^4(``\KI_5O30@`-BLX!`8LI%0^J0@`,RBD!#HM"``N+:GQ`
MDBX!`@NB_4+30G@-JNU'0/G)_5O3*14.JDM\0)*M`0&+8P`"RBD!#8OM_4+3
MK7D/JF,`#XI"``W*8P`*RD(`#HIC``R+0@`+RBD!`PM"``J+K'U`DN\K2:DC
M_5O38Q0)JN\!`8M!`0&+XT$CBV\``@MP``*+P_U"T^+]6]-C>`ZJ0A0/JB)`
M(HNA`0/*(0`)BB$`#,HA``N+*_U"TTX``8M"``$+:WD)JB%TG=+I4T#Y2OQ;
MTTH5`JHAVZWR*0$!BRI!*HMI``O**0$02BD!#(M-`0D+4`$)B^Q70/FJ_5O3
MZ?U"TTH5#:HI>0^JC`$!BXI!*HML`0G*C`$.2H-!(XM,`0,+3@$#BT/\0M-C
M>`*JBOU;T^);0/E*%0RJ0@`!BTI`*HLB`0/*0@`02D)`*XM+`0(+4`$"BZ+]
M0M-">`VJ:OU;T^U?0/E*%0NJK0$!BZI!*HMM``+*K0$.2JE!*8M.`0D+3P$)
MBXG]0M,I>0RJROU;T^QC0/E*%0ZJC`$!BXI!*HM,``G*C`$02H-!(XM-`0,+
M4`$#BV/]0M-C>`NJJOU;T^MG0/E*%0VJ:P$!BVI!*HLK`0/*:P$/2F)!(HM,
M`0(+3P$"B^MK0/F*_5O3POU"TTH5#*I">`ZJ:P$!BVI!*HMK``+*:P$02FE!
M*8M+`0D+4`$)BZG]0M,I>0VJ:OU;T^UO0/E*%0NJK0$!BZI!*HM-``G*K0$/
M2J-!(XM.`0,+3P$#BX/]0M-C>`RJROU;T^QS0/E*%0ZJC`$!BXI!*HLL`0/*
MC`$02H)!(HM-`0(+4`$"BV+]0M-">`NJJOU;T^MW0/E*%0VJ:P$!BVI!*HMK
M``+*:P$/2FE!*8M,`0D+3P$)B^M[0/F*_5O3R?U"TTH5#*HI>0ZJ:P$!BVI!
M*HM+``G*:P$02F-!(XM+`0,+4`$#BZ/]0M-C>`VJ:OU;T^U_0/E*%0NJK0$!
MBZI!*HLM`0/*K0$/2J)!(HM.`0(+3P$"BX+]0M-">`RJROU;T^R#0/E*%0ZJ
MC`$!BXI!*HML``+*C`$02HE!*8M-`0D+4`$)BVG]0M,I>0NJJOU;T^N'0/E*
M%0VJ:P$!BVI!*HM+``G*:P$/2F-!(XM,`0,+3P$#B^N+0/F*_5O3P_U"TTH5
M#*IC>`ZJ:P$!BVI!*HLK`0/*:P$02F)!(HM+`0(+3@$"BZ+]0M-->`VJ:OU;
MT^*/0/E*%0NJ0@`!BTI`*HMB``W*0@`/2DE`*8N"_4+33P$)BTH!"0M,>`RJ
MXI-`^4G]6],I%0JJ0@`!BTE`*8NB`0S*0@`.2D-`(XMB_4+3+@$#BRD!`PM+
M>`NJXI=`^2/]6]-C%`FJ0@`!BT-`(XN"`0O*0@`/2D)`+8MM``*+8P`""T+]
M0M-/>`JJ:OQ;T^*;0/E*%0.J0@`!BTH!`HMB`0_*0@`.2D)`+(M.`0(+(OU"
MTT)X":KIGT#YROU;TTH5#JHA`0&+2@$!B^$!`LHA``U*(4`KB^FC0/E-`0$+
M8?Q"TR%X`ZJJ_5O3@YN7TDL``:ICX['R2A4-JBD!`XMK`0Z*2@$)BRD``@IK
M`0FJ:4$OBTP!"0O)_4+3+GD.JNFG0/F*_5O3*P`.JDH5#*HI`0.+:P$-BDH!
M"8O)`0$*:P$)JF)!(HM1`0(+HOU"TTUX#:KBJT#Y*OY;T\L!#:I*%1&J0@`#
MBVL!#(I*`0*+H@$."FL!`JIA02&+4`$!"X']0M,L>`RJX:]`^0K^6].K`0RJ
M2A40JB$``XMK`1&*2@$!BX$!#0IK`0&J(?Y"TVE!+HM/`0D+*7@1JN&S0/GJ
M_5O3BP$)JDH5#ZHA``.+:P$0BDH!`8LA`0P*:P$!J@'^0M-B02V+3@$""R)X
M$*KAMT#YROU;TRL!`JI*%0ZJ(0`#BVL!#XI*`0&+00`)"FL!`:IA02R+Z[M`
M^4P!`0OA_4+3BOU;TR%X#ZIK`0.+2A4,JDH!"XM+``&J+0`""FL!#HIK`0VJ
M:4$IBTT!"0O)_4+3+GD.JNF_0/FJ_5O3*P`.JDH5#:HI`0.+:P$,BDH!"8O)
M`0$*:P$)JF)!(HM1`0(+@OU"TTQX#*KBPT#Y*OY;T\L!#*I*%1&J0@`#BVL!
M#8I*`0*+@@$."FL!`JIA02&+4`$!"Z']0M,M>`VJX<=`^0K^6].+`0VJ2A40
MJB$``XMK`1&*2@$!BZ$!#`IK`0&J(?Y"TVE!+HM/`0D+*7@1JN'+0/GJ_5O3
MJP$)JDH5#ZHA``.+:P$0BDH!`8LA`0T*:P$!J@'^0M-B02R+3`$""R)X$*KA
MST#YBOU;TRL!`JI*%0RJ(0`#BVL!#XI*`0&+00`)"FL!`:IA02V+Z]-`^4X!
M`0OA_4+3ROU;TR%X#ZIK`0.+2A4.JDH!"XM+``&J+0`""FL!#(IK`0VJ:4$I
MBTT!"0N)_4+3+'D,JNG70/FJ_5O3*P`,JDH5#:HI`0.+:P$.BDH!"8N)`0$*
M:P$)JF)!(HM0`0(+POU"TTYX#JKBVT#Y"OY;TXL!#JI*%1"J0@`#BVL!#8I*
M`0*+P@$,"FL!`JIA02&+3P$!"Z']0M,M>`VJX=]`^>K]6]/+`0VJ2A4/JB$`
M`XMK`1"*2@$!BZ$!#@IK`0&J`?Y"TVE!+(M,`0D+*7@0JN'C0/F*_5O3JP$)
MJDH5#*HA``.+:P$/BDH!`8LA`0T*:P$!JN']0M-B02Z+4`$""R)X#ZKAYT#Y
M"OY;TRL!`JI*%1"J(0`#BVL!#(I*`0&+00`)"FL!`:IA02V+3P$!"X']0M,L
M>`RJX>M`^>K]6]-*%0^J2P`,JB$``XMK`1"**D`JBX$!`@IK`0&J`?Y"TVE!
M*8LK>!"J3@$)"U$!"8OA[T#YR?U;TRD5#JHA``.+(T`IBXD!"ZIA`0P**0$/
MBBD!`:KA_4+3(D$BBR]X#ZIM``(+:@`"B^'S0/FC_5O38Q0-JL(ZF-)"3+GR
M(0`"BR-`(XMA`0_*(0`12B%`+(ML``$+<``!B\']0M,I>`ZJ@_U;T^'W0/EC
M%`RJ(0`"BR-`(XOA`0G*(0`*2B%`*XMK``$+;@`!BZ']0M,C>`VJ:OU;T^'[
M0/E*%0NJ(0`"BRI`*HLA`0/*(0`02B%`+XM-`0$+3P$!BX']0M,A>`RJJOU;
MT^S_0/E*%0VJC`$"BXI!*HML``'*C`$.2HE!*8M,`0D+3@$)BVG]0M,I>0NJ
MBOU;T^L#0?E*%0RJ:P$"BVI!*HLK``G*:P$/2F-!(XM+`0,+4`$#BZ/]0M-C
M>`VJ:OU;T^T'0?E*%0NJK0$"BZI!*HLM`0/*K0$.2J%!(8M.`0$+3P$!BX']
M0M,A>`RJROU;T^P+0?E*%0ZJC`$"BXI!*HML``'*C`$02HE!*8M-`0D+4`$)
MBVG]0M,I>0NJJOU;T^L/0?E*%0VJ:P$"BVI!*HLK``G*:P$/2F-!(XM,`0,+
M3P$#B^L30?F*_5O3P_U"TTH5#*IC>`ZJ:P$"BVI!*HLK`0/*:P$02F%!(8M+
M`0$+4`$!BZ']0M,A>`VJ:OU;T^T70?E*%0NJK0$"BZI!*HMM``'*K0$/2JE!
M*8M.`0D+3P$)BXG]0M,I>0RJROU;T^P;0?E*%0ZJC`$"BXI!*HLL``G*C`$0
M2H-!(XM-`0,+4`$#BV/]0M-C>`NJJOU;T^L?0?E*%0VJ:P$"BVI!*HLK`0/*
M:P$/2F%!(8M,`0$+3P$!B^LC0?F*_5O3P?U"TTH5#*HA>`ZJ:P$"BVI!*HMK
M``'*:P$02FE!*8M+`0D+3@$)BZG]0M,I>0VJ:OU;T^TG0?E*%0NJK0$"BZI!
M*HLM``G*K0$/2J-!(XM-`0,+3P$#BX/]0M-C>`RJJOU;T^PK0?E*%0VJC`$"
MBXI!*HLL`0/*C`$.2H%!(8M,`0$+3@$!BV']0M,A>`NJBOU;T^LO0?E*%0RJ
M:P$"BVI!*HMK``'*:P$/2FE!*8M+`0D+3P$)BZG]0M,J>0VJ:?U;T^TS0?DI
M%0NJK0$"BZE!*8LM``K*K0$.2J-!(XLN`0.+(P$#"^TW0?F)_4+3+'D,JFG\
M6],I%0.JK0$"BX1`+(NI02F+30$,RJT!#TJA02&++0$!"R\!`8OI.T'Y8?U"
MTRMX"ZJA_5O3*0$"BR$4#:HA``F+B0$+RBD!#DHJ02J+:?Q"TR$`"@LC>0.J
MZC]!^6D!`\HI`0]*8P`&"T(!`HLJ_%O32A4!JB(!`HLA``@+1`$$BT(`!`L"
M!`"IH?U"TR%X#:HA``4+`0P!J6$!!PL!$`#YP```\`#41_GB1T'Y`0!`^4(`
M`>L!`(#2H0``5/]#"I']>\&HOR,#U<`#7];6\O^7'R`#U3\C`]7]>[^I`!"`
MTOT#`)'<\O^7(@``L!\8`/D?>`"Y7WS`/2(``+!>@,`](@``L!]X`*U?A,`]
M'PB`/?U[P:B_(P/5P`-?UC\C`]7]>[NI_0,`D?-3`:GT`P"J0'Q`D_5;`JGV
M`P"JE>(`D?=C`ZGX`P&JA(I"J8,,``N?``/K0I2"FD!T0(N#@@*I@'I`N<`$
M`#7?_@!Q+0,`5-=^!E/Y(P#Y^08`4?,#&*KW9AI3%P,7BQ\@`]4?(`/5'R`#
MU7UR0*W@`Q2J?WI!K7,"`9&]<@"MOWH!K8K[_Y=_`A?K`?__5!@#`9$`"(!2
MU@(!4=8:&4LX8Z";^2-`^<)^0)/A`QBJX`,5JC;R_Y>6>@"Y\U-!J?5;0JGW
M8T.I_7O%J+\C`]7``U_6$PB`4G,"`$M_`A9KH,(@BW/2EAIB?D"3*/+_EX!Z
M0+E@`@`+@'H`N1\``7'A_?]4U@(32QC#,XO@`Q2J9_O_E\O__Q<_(P/5_7N\
MJ2/@`)'B#X`2_0,`D?-3`:GT`P"J\P,!JO5;`JDUV$*IH"(#4P$$`!%BR"`X
M8,`ABS_@`''-"P!4`@B`4D(``4L!`(!2XQ\`^4)\0).\\O^7X`,3JD[[_Y<?
M!`!/XQ]`^7^"@SQ_&`#Y?_P`K=\"9Y[`?AA3^@=P?_L'>'^_`F>>_`=H?_T'
M<'_^!WA_'P!GGN`#$ZI?!P-N?P<%;M\>!TZ?!PENOP<+;M\'#6Z_'@].?SH`
M_3;[_Y=@`D#Y`/Q8TX`"`#E@`D#Y`/Q0TX`&`#E@`D#Y`/Q(TX`*`#E@`D#Y
M@`X`.6`&0/D`_%C3@!(`.6`&0/D`_%#3@!8`.6`&0/D`_$C3@!H`.6`&0/F`
M'@`Y8`I`^0#\6-.`(@`Y8`I`^0#\4-.`)@`Y8`I`^0#\2-.`*@`Y8`I`^8`N
M`#E@#D#Y`/Q8TX`R`#E@#D#Y`/Q0TX`V`#E@#D#Y`/Q(TX`Z`#E@#D#Y@#X`
M.6`20/D`_%C3@$(`.6`20/D`_%#3@$8`.6`20/D`_$C3@$H`.6`20/F`3@`Y
MX`,3JO5;0JGS4T&I_7O$J+\C`]5)\O\7`@>`4D(``4L!`(!20GQ`DV#R_Y>K
M__\7'R`#U1\@`]7#``#P8P1`^?+Q_Q<?(`/5_7N_J?T#`)']>\&HP`-?U@$`
M`@``````)7,O)7,````O<')O8R]S96QF+V5X90``1'EN84QO861E<CHZ8F]O
M=%]$>6YA3&]A9&5R``````!);G1E<FYA;',Z.E!!4CHZ0D]/5`````!E>&4`
M`````"]P<F]C+R5I+R5S```````N`````````%!!4E]414U0``````````!0
M05)?4%)/1TY!344`````.@`````````O`````````"5S)7,E<P``4$523#5,
M24(``````````%!%4DQ,24(`4$523#5/4%0``````````%!%4DQ)3P``4$%2
M7TE.251)04Q)6D5$`%!!4E]34$%73D5$``````!005)?0TQ%04X`````````
M4$%27T1%0E5'`````````%!!4E]#04-(10````````!005)?1TQ/0D%,7T1%
M0E5'``````````!005)?1TQ/0D%,7U1-4$1)4@````````!005)?5$U01$E2
M````````4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````````
M`#$`````````;'-E96L@9F%I;&5D`````')E860@9F%I;&5D``````!,1%],
M24)205)97U!!5$@`4UE35$5-```E,#)X`````'!A<BT`````)7,E<R5S)7,`
M`````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E
M<R!F86EL960@*&5R<FYO/25I*0H````````E<SH@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R
M>2!Y;W5R(&]P97)A=&EO;BD*````````4$%42`````!P87)L`````"YP87(`
M````<VAO<G0@<F5A9````````"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE
M=25S````)7,E<W1E;7`M)74M)74E<P``````````&`````````!P97)L````
M`#``````````4$%2.CI086-K97(Z.E9%4E-)3TX`````,2XP-C0```!5;F%B
M;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``````````)7,Z(&-R96%T
M:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H
M97)R;F\])6DI"@``````````+64````````M+0```````%5315(`````55-%
M4DY!344``````````%1-4$1)4@``5$5-4$1)4@!414U0`````%1-4```````
M+W1M<`````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB
M)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A
M8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O9F9S971?
M<VEZ92P@)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-04=)0R`]
M(")<;E!!4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@<&%C
M:R@B3B(I"B1C86-H95]N86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!1TE#(#T@
M(E!+7#`P,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY("@D9F@I
M(#T@0%\["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM
M>2`D<VEZ92`]("US("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M("@D<VEZ
M92TQ*2`E("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I<R!A(&UU
M;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I('L*<V5E
M:R`D9F@L("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?<VEZ92`K
M(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F
M+"`D4$%27TU!1TE#*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K("1I.PI]"B1P
M;W,@+3T@)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R7W1E
M;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![
M(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY
M("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I
M.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I
M;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N
M;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D
M<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W
M($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&
M:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N
M8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I
M;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@
M+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D
M<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD
M>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H
M;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D
M978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE
M9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL
M96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I
M(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A
M<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM
M>2`E<WES(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@
M)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN
M?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@
M*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P
M<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI
M.PI?<V5T7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@
M(B1%3E9[4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T87)T7V]F
M7T9)3$5?<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L("1324=[7U]705).7U]]
M(#T@<W5B('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA
M;64I('L*;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R;V=N86UE
M(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E<R!%<G)N
M;RYP;0IL87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M
M86=I8R@J7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N
M)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P
M<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!005(@;6%G
M:6,@870@<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC
M7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!0TA%(BDL
M(#`["G)E860@7T9(+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B
M=68@;F4@(EPP0T%#2$4B("8F("1B=68@;F4@(EPP0TQ%04XB*2!["F]U=',H
M(DYO(&-A8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]"F]U=',H
M<7%;0V%C:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI.PIS965K(%]&2"P@)&UA
M9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@)&)U
M9BP@)$9)3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A8VLH(DXB
M+"`D8G5F*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@:7,@
M)&]F9G-E="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E
M=%]S:7IE("T@)&]F9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C=&EO;B`]
M('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@
M-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T
M(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@
M)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U
M;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA
M+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D
M97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@
M7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U
M9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L
M?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E
M>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L
M;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F
M:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS92!["B1-;V1U;&5#86-H97LD
M9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@
M/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK*SL*
M?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY
M("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE
M(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD;6]D=6QE
M?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E7VQI<W1[
M)&UO9'5L97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D
M=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I
M;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R
M(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO
M9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@
M,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E
M7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF;RT^
M>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I
M;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D(5T[
M"G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N
M)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!8
M4TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE
M879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@
M)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU
M;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!
M3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@
M)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE
M;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1F:6QE;F%M97T["GT*:68@*"1B=68@;F4@)%!+6DE07TU!
M1TE#*2!["F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO
M;B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R
M=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R
M="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D
M;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]21553
M17T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L
M96TI"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P
M=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L
M:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS
M("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D
M05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%2
M7T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@
M<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@
M>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L
M87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]
M"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H
M)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H
M)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2![
M"B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N
M9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q
M.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R
M(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE
M;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H
M0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E
M("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$
M:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB
M4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N
M<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E
M<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E
M($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z
M:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L
M("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D
M(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@
M<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A7W!A<B`]
M(&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H
M)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A
M(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O
M;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ
M<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A
M<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB
M)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q("102UI)
M4%]-04=)0SL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I
M('P@24\Z.D9I;&4Z.D]?4D174B@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*
M,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D
M(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E
M<CL*:68@*&1E9FEN960@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD@>PIR96%D
M(%]&2"P@)&QO861E<BP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;CL*?2!E;'-E
M('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A
M)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R
M96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"B1F:"T^
M<')I;G0H)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R
M('1O("(D;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ
M2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I
M;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"
M4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE
M("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO
M)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R
M($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,[
M"FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@
M("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R
M96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@
M)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I
M.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@
M/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D
M:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=
M*R\H+BHI)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2![
M"B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@
M(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I
M.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE
M>'0@:68@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@
M86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F
M*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M
M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE
M*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@
M)"\@/2!U;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I
M92!Q<5M#86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H
M/CL*8VQO<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD
M8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D52
M0D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ
M1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D
M9FEL92P@)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@
M;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV
M93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH
M)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%
M<G)O<B!W<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D(5T["F]U
M=',H<7%;5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II<"D@>PHD
M>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TL*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@;V8@(B1O
M=70B73L*?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@>PHD9F@M/G!R:6YT*")<
M,$-,14%.(BD["GT*96QS92!["FEF("@A9&5F:6YE9"`D8V%C:&5?;F%M92D@
M>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*<V5E:R`D9F@L(#`L
M(#`["B1C='@M/F%D9&9I;&4H)&9H*3L*<V5E:R`D9F@L(#`L(#(["B1C86-H
M95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE(#T@<W5B
M<W1R("1C86-H95]N86UE+"`P+"`D8V%C:&5?;F%M95]S:7IE.PHD8V%C:&5?
M;F%M92`N/2`B7#`B('@@*"1C86-H95]N86UE7W-I>F4@+2!L96YG=&@@)&-A
M8VAE7VYA;64I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`HB7#!#04-(12(I
M.PI]"FUY("1O9F9S970@/2`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BD[
M"B1F:"T^<')I;G0H<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!1TE#*3L*
M)&9H+3YC;&]S92!O<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I;&5R(&]F
M("(D;W5T(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S
M="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D[
M"G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA
M;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;
M9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3
M:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"1Z
M:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C
M:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z
M:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU
M;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`[
M"B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S*")%>'1R
M86-T:6YG('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@
M>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D
M;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI
M<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA
M;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O
M"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX
M.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE
M.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE
M*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O
M;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N
M86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=
M*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B
M('1O("(D9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL
M94YA;65D*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*
M;W(@9&EE('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E
M<W1?;F%M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@
M(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N
M86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@
M+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@
M72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C
M+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@
M<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]
M($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D
M<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE
M+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ
M;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S
M('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L
M:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U
M:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR
M97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R
M;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R
M.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@
M1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<[
M"G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER
M92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I
M<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A
M=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0
M;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR
M97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L
M('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T
M:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T[
M"F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V
M86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!]
M.PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@
M>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-
M4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R
M96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2
M(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M
M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P
M871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V
M86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*
M:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE
M(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED
M*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@
M)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0IM
M>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B
M2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@)&-A
M8VAE7V1I<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER(#T@
M(G1E;7`M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R
M;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T[
M"FEF("@H;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI(#X]
M(#`I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ
M90HM(&QE;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR96%D("1F:"P@
M)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<,$-!0TA%
M(BD@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE
M"BT@;&5N9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P.PIR
M96%D("1F:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S+UPP
M+R]G.PHD8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@)&9H
M.PI]"FEF("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B
M.PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES>U]D
M96QI;7TD8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%3E9[
M4$%27U1%35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@
M:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI
M+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO
M9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU
M;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN
M86UE+B0D(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M
M92D*)B8@*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R
M(&1I92!Q<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D
M("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T
M96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR
M971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E
M9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-
M17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\
M?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE
M+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H
M)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@
M,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N
M86UE+"`D<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G
M/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B
M)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X
M97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y
M<WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@
M)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D
M:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D
M9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II
M9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH
M*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA
M<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U
M8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%2
M7U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]
M*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B
M.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG
M971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ
M1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@
M<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]
M+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R
M7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q
M("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`]
M(#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%
M(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@
M*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D
M7R)](#T@)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)0
M05)?1TQ/0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T
M92`D14Y6>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D
M<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE
M;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER
M92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I
M9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E
M87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP
M"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#
M+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I
M92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M
M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P
M<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@
M/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z
M.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ
M7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T52
M4D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*`'!E<FQX<VDN8P``````
M````0T%#2$4```$C16<`````B:O-[P````#^W+J8`````'94,A``````\.'2
MPP````````````````$;`SL,`0``(````."'__^D!@``((K__R0!``"`BO__
M.`$``+"*__],`0``[(K__V`!``!`B___B`$``&"+__^@`0``8(S__PP"```$
MC?__.`(``(R.__^0`@``P)#__\P"``#$D?__``,``$"2__\H`P``<)+__SP#
M``!@D___<`,``&B3__^$`P``P)7___`#````EO__&`0``(27__]X!```H)S_
M_[@$```@G?__X`0``,"=___\!```$)___T`%``!`G___9`4``&"@__^H!0``
MP*;__S0&``#DJ/__;`8```"J___8!@```+O__P@'``!(N___+`<``&R\__]L
M!P``0+[__Z`'````````$``````````!>E(`!'@>`1L,'P`0````&````/2(
M__\T`````$$''A`````L````0(G__S``````````$````$````!<B?__/```
M```````D````5````(2)__]0`````$$M00X@G02>`T*3`D[>W=,.`$$M````
M%````'P```"PB?__"```````````````:````)0```"XB?__^`````!!+4$.
M0)T(G@="EP*8`463!I0%0I8#E018UM5$WMW7V-/4#@!!+4$.0),&E`65!)8#
MEP*8`9T(G@<M3M;50][=U]C3U`X`02U!#D"3!I0%EP*8`9T(G@<M````*```
M```!``!,BO__I`````!!+4$.L`%#G02>`T*3`E<*T]W>#@!!+4$+``!4````
M+`$``,2*__^(`0```$$M00[0`4.=!IX%1I0#DP1$U--)W=X.`$$M00[0`9,$
ME`.=!IX%+4&6`94">0K4TT'6U4$+2=/4U=9!E`.3!$&6`94"````.````(0!
M``#TB___-`(```!!+4$.8$&=")X'0I,&E`5%E026`Y<"F`$"1PK7V-76T]3=
MW@X`02U!"P``,````,`!``#LC?__!`$```!!+4$.,)T&G@5%#M`@DP24`Y4"
M90H.,$/>W=73U`X`02U!"R0```#T`0``O([__W``````02U!#B"=!)X#19,"
ME`%-WMW3U`X`02T0````'`(``!"/__\P`````````#`````P`@``+(____``
M````02U!#C"=!IX%1`[@0),$E`-O"@XP0][=T]0.`$$M00M!E0(0````9`(`
M`.B/__\(`````````&@```!X`@``W(___U@"````02U!#E"="IX)10[@(9,(
ME`>5!I8%7PH.4$/>W=76T]0.`$$M00M)F`-#F@%"EP1!F0)D"M=!V$'90=I!
M"V@*UT'80=E!VD$+0]?8V=I!EP1!F`-!F0)!F@$``"0```#D`@``R)'__S0`
M````02U!#B"=!)X#0Y,"1M[=TPX`02T```!<````#`,``."1__^$`0```$$M
M00X@G02>`T,.P"!(DP)!E`%I"M-"U$$.($'>W0X`02U!"T'30=1+#B!!WMT.
M`$$M00[`(),"E`&=!)X#+4P*TT+40@M!T]1!DP)!E`$\````;`,```23__\0
M!0```$$M00Y@0YT*G@E"DPB4!T65!I8%EP28`YD"`RP!"MG7V-76T]3=W@X`
M02U!"P``)````*P#``#@E___@`````!!+4$.($.=`IX!5@K=W@X`02U!"P``
M`!@```#4`P``.)C__Z``````02U!#L`"09T:GAE`````\`,``+R8__]0`0``
M`$$M00XPG0:>!40.L(`$DP24`Y4"E@%"#L"`!'H*#K"`!$$.,$/>W=76T]0.
M`$$M00L``"`````T!```R)G__R@`````02U!#A"=`IX!1M[=#@!!+0```$``
M``!8!```U)G__QP!````02U!#E!!G0:>!4*5`I8!1),$E`-9"M76T]3=W@X`
M02U!"V`*U=;3U-W>#@!!+4$+````B````)P$``"PFO__8`8```!!+4$.H`-!
MG0R>"T*7!I@%1),*E`E"E0B6!UV:`YD$09P!FP("?0K:V4'<VT37V-76T]3=
MW@X`02U!"P*-V=K;W$[7V-76T]3=W@X`02U!#J`#DPJ4"94(E@>7!I@%F02:
M`YL"G`&=#)X++0)+V=K;W$&:`YD$09P!FP(T````*`4``(2@__\D`@```$$M
M00Y00YT(G@="DP:4!465!)8#EP("7@K7U=;3U-W>#@!!+4$+`#0```!@!0``
M<*+__P0!````02U!#C!!G02>`T*3`I0!70K3U-W>#@!!+4$+6@K3U-W>#@!!
M+4$+,````)@%```T@?__$`(```!!+4$.8$&=!IX%2),$E`.5`I8!`E<*U=;3
MU-W>#@!!+4$+`"P```#,!0``(*/___P0````0RU!#A"=`IX!10Z@!0,R!`H.
M$$'>W0X`02U!"P```"````#\!0``\+/__T@`````02U!#A"=`IX!3M[=#@!!
M+0```#P````@!@``%+3__R0!````02U!#E"="IX)0I,(E`=#E0:6!4.7!)@#
M39D"5ME)"M[=U]C5UM/4#@!!+4$+```P````8`8``/BT___,`0```$$M00Y`
MG0B>!T23!I0%0Y4$E@,"8@K>W=76T]0.`$$M00L`$````)0&``"8MO__#```
M````````````!````!`````!````1TY5```````#````!P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````&`=````````#!T`
M```````!`````````!`#`````````0`````````@`P````````$`````````
M*@,````````,`````````/@5````````#0````````!L4````````!D`````
M````@/L!```````;``````````@`````````&@````````"(^P$``````!P`
M````````"`````````#U_O]O`````+`"````````!0````````"H"0``````
M``8`````````T`(````````*`````````&$#````````"P`````````8````
M`````!4````````````````````#`````````*#]`0```````@````````"(
M!0```````!0`````````!P`````````7`````````'`0````````!P``````
M````#@````````@`````````<`(````````)`````````!@`````````'@``
M```````(`````````/O__V\``````0``"`````#^__]O`````*`-````````
M____;P`````"`````````/#__V\`````"@T```````#Y__]O``````X`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````0%@```````!`6````````$!8````````0%@``
M`````!`6````````$!8````````0%@```````!`6````````$!8````````0
M%@```````!`6````````$!8````````0%@```````!`6````````$!8`````
M```0%@```````!`6````````$!8````````0%@```````!`6````````$!8`
M```````0%@```````!`6````````$!8````````0%@```````!`6````````
M$!8````````0%@```````!`6````````$!8````````0%@```````!`6````
M````$!8````````0%@```````!`6````````$!8````````0%@```````!`6
M````````$!8````````0%@```````!`6````````$!8````````0%@``````
M`!`6````````$!8````````0%@```````!`6````````$!8````````0%@``
M`````!`6````````$!8````````0%@```````!`6````````$!8````````0
M%@```````!`6````````$!8````````0%@```````!`6````````D/L!````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````&@``````````````````"``"```````*4$%2+G!M"@``````
M````8%0```````#P4```````````````````X%$```````!`5````````$A4
M````````4%0```````!85```````````````````*%0````````P5```````
M````````````:%0```````!'0T,Z("A-86=E:6$@,34N,2XP+3$N;6=A,3`I
M(#$U+C$N,```+G-H<W1R=&%B`"YN;W1E+F=N=2YB=6EL9"UI9``N:6YT97)P
M`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N
M=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`+G1E>'0`+F9I
M;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N;F]T92Y!0DDM
M=&%G`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A
M=&$`+F)S<P`N8V]M;65N=```````````````````````````````````````
M```````````````````````````````````````````````````+````!P``
M``(`````````<`(```````!P`@```````"0````````````````````$````
M````````````````'@````$````"`````````)0"````````E`(````````;
M`````````````````````0```````````````````"8```#V__]O`@``````
M``"P`@```````+`"````````'``````````$``````````@`````````````
M```````P````"P````(`````````T`(```````#0`@```````-@&````````
M!0````,````(`````````!@`````````.`````,````"`````````*@)````
M````J`D```````!A`P```````````````````0```````````````````$``
M``#___]O`@`````````*#0````````H-````````D@`````````$````````
M``(``````````@````````!-````_O__;P(`````````H`T```````"@#0``
M`````&``````````!0````(````(````````````````````7`````0````"
M```````````.``````````X```````!P`@````````0`````````"```````
M```8`````````&8````$````0@````````!P$````````'`0````````B`4`
M```````$````%0````@`````````&`````````!P`````0````8`````````
M^!4```````#X%0```````!@````````````````````$````````````````
M````:P````$````&`````````!`6````````$!8```````#0`P``````````
M````````$````````````````````'8````!````!@``````````&@``````
M```:````````;#8``````````````````$````````````````````!\````
M`0````8`````````;%````````!L4````````!0````````````````````$
M````````````````````@@````$````"`````````(!0````````@%``````
M``"@00``````````````````$````````````````````(H````!`````@``
M```````@D@```````""2````````#`$```````````````````0`````````
M``````````"8`````0````(`````````,),````````PDP```````*@&````
M```````````````(````````````````````H@````<````"`````````-B9
M````````V)D````````@````````````````````!```````````````````
M`+`````.`````P````````"`^P$``````(#[````````"```````````````
M``````@`````````"`````````"\````#P````,`````````B/L!``````"(
M^P````````@````````````````````(``````````@`````````R`````8`
M```#`````````)#[`0``````D/L````````0`@````````4`````````"```
M```````0`````````-$````!`````P````````"@_0$``````*#]````````
M8`(```````````````````@`````````"`````````#6`````0````,`````
M```````"``````````$``````(@````````````````````(````````````
M````````W`````@````#`````````(@``@``````B``!```````H````````
M````````````"````````````````````.$````!````,```````````````
M`````(@``0``````)`````````````````````$``````````0`````````!
M`````P````````````````````````"L``$``````.H`````````````````
2```!````````````````````
